@@ -98,7 +98,7 @@ class MRP():
         opened = []
 
         # Set visited 
-        debug_print(f"Current node: {current_node.name}")
+        # debug_print(f"Current node: {current_node.name}")
         self.visited_nodes.add(current_node)
         
         # Save the traversed path
